%Empirical example for the paper "Confidence Bands
%for Impulse Responses: Bonferroni versus Wald" by 
%Helmut Luetkepohl, Anna Staszewska-Bystrova and Peter Winker, 2014.

clear
clc

n=5000;   %number of bootstrap replications
h=18;     %horizon (shock occurs at h=0)
sl=0.1;   %1-nominal coverage rate
nlags=24;  %number of lags in the VAR
%**************************************************************************
% Load series
dprod= load (['dprod.asc']);
rea= load (['rea.asc']);
rpo= load (['rpo.asc']);

mx=[dprod rea rpo];
[ct,nvar]=size(mx);

%estimation
[bm, um, sigmam, ym, xm] = olsvar(mx, nlags);

        %bootstrap replicates of the response functions, responses based on
        %bias-corrected estimators and bootstrapped values of the Wald
        %statistic
        [bp1,resp,wb]=bpaths(mx,nlags,nvar,ct,h,n);

        [wsort,wind]=sort(wb);

        naive=zeros(2*nvar^2,h+1);                      %naive bands
        W=zeros(2*nvar^2,h+1);                          %W bands
        Wa=zeros(2*nvar^2,h+1);                         %Wa bands
        WBa=zeros(2*nvar^2,h+1);                        %WBa bands
        JWa=zeros(2*nvar^2,h+1);                        %JWa bands
        JWBa=zeros(2*nvar^2,h+1);                       %JWBa bands

        for c=1:nvar^2
            bb=bp1(n*(c-1)+1:c*n,:);
            bbs=bb(wind(1:round((1-sl)*n))',:);
            W(2*c-1,:)=min(bbs,[],1);
            W(2*c,:)=max(bbs,[],1);
            Wa(2*c-1:2*c,:)=adjW(nvar,sl,n,bb,wind,h);
            [WBa(2*c-1,:),WBa(2*c,:)]=adjB(h+1,W(2*c-1,:),W(2*c,:),bb,n,sl);
        end

        JWa=JadjW(nvar,sl,n,bp1,wind,h,W);
        JWBa=JadjB(h+1,W,bp1,n,sl,nvar);

        B=zeros(2*nvar^2,h+1);                          %B bands
        Ba=zeros(2*nvar^2,h+1);                         %Ba bands
        B1=zeros(2,h+1);

        for c=1:nvar^2
            bb1=bp1(n*(c-1)+1:c*n,:);
            if bb1(:,1)==zeros(n,1)
                B1(1,:)=quantile(bb1,sl/(2*(h)));
                B1(2,:)=quantile(bb1,1-sl/(2*(h)));
            else
                B1(1,:)=quantile(bb1,sl/(2*(h+1)));
                B1(2,:)=quantile(bb1,1-sl/(2*(h+1)));
            end
               naive(2*c-1,:)=quantile(bb1,sl/2);
               naive(2*c,:)=quantile(bb1,1-sl/2);

            B(2*c-1:2*c,:)=B1;
            [Ba(2*c-1,:),Ba(2*c,:)]=adjB(h+1,B(2*c-1,:),B(2*c,:),bb1,n,sl);
        end

        JB=zeros(2*nvar^2,h+1);                         %JB bands
        JBa=zeros(2*nvar^2,h+1);                        %JBa bands

        mm=nvar^2*h+nvar*((nvar+1)/2);
        for c=1:nvar^2
            bb1=bp1(n*(c-1)+1:c*n,:);
            JB(2*c-1,:)=quantile(bb1,sl/(2*(mm)));
            JB(2*c,:)=quantile(bb1,1-sl/(2*(mm)));
        end

        [JBa]=JadjB(h+1,JB,bp1,n,sl,nvar);

        JBstar=zeros(2*nvar^2,h+1);                     %JBstar bands     
        JBastar=zeros(2*nvar^2,h+1);                    %JBastar bands
        Bj1H=zeros(2,h+1);

        mm=nvar^2*h+nvar*((nvar+1)/2);
        if mm<=nvar^2*nlags+nvar*(nvar+1)/2
            JBstar=JB;
            JBastar=JBa;
        end
        if mm>nvar^2*nlags+nvar*(nvar+1)/2
            mmstar=nvar^2*nlags+nvar*(nvar+1)/2;
            for c=1:nvar^2
                bb1=bp1(n*(c-1)+1:c*n,:);
                JBstar(2*c-1:2*c,:)=JB_star(bb1,sl,mmstar,h,n,nvar,nlags);
            end
        end

        [JBastar]=JadjB(h+1,JBstar,bp1,n,sl,nvar);

r=[0;ones(h,1)];
rr=cumsum(r);
figure;
subplot(3,3,1)
plot(rr, naive(1,:),'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(2,:),'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(1,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,2)
plot(rr, naive(3,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(4,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(2,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,3)
plot(rr, naive(5,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(6,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(3,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,4)
plot(rr, naive(7,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(8,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(4,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,5)
plot(rr, naive(9,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(10,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(5,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
ylim([-1 7]);
hold off
subplot(3,3,6)
plot(rr, naive(11,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(12,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(6,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,7)
plot(rr, naive(13,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(14,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(7,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,8)
plot(rr, naive(15,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, naive(16,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(8,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,9)
p1=plot(rr, naive(17,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
p2=plot(rr, naive(18,:), 'LineWidth',1,  'Color','black','Marker','v','MarkerSize',2);
hold on
p3=plot(rr, resp(9,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
ylim([-1 11]);
hold off
h1=legend([p1 p3],{'90% individual confidence intervals','response'},'Orientation','horizontal');
p = get(h1,'Position');
p(1) = 0.13;
p(2) = 0;
set(h1,'Position',p);

figure;
subplot(3,3,1)
plot(rr, W(1,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(2,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(1,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(2,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(1,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(2,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(1,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(2,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(1,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,2)
plot(rr, W(3,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(4,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(3,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(4,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(3,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(4,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(3,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(4,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(2,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,3)
plot(rr, W(5,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(6,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(5,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(6,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(5,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(6,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(5,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(6,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(3,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,4)
plot(rr, W(7,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(8,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(7,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(8,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(7,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(8,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(7,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(8,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(4,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,5)
plot(rr, W(9,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(10,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(9,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(10,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(9,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(10,:),'-.',  'LineWidth',2,'Color','black');
hold on
plot(rr, Ba(9,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(10,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(5,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,6)
plot(rr, W(11,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(12,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(11,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(12,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(11,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(12,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(11,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(12,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(6,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,7)
plot(rr, W(13,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(14,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(13,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(14,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(13,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(14,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(13,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(14,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(7,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,8)
plot(rr, W(15,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(16,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(15,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(16,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(15,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(16,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(15,:),'--', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(16,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(8,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,9)
p1=plot(rr, W(17,:),'LineWidth',2, 'Color','black');
hold on
p2=plot(rr, W(18,:),'LineWidth',2, 'Color','black');
hold on
p3=plot(rr, B(17,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p4=plot(rr, B(18,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p5=plot(rr, Wa(17,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p6=plot(rr, Wa(18,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p7=plot(rr, Ba(17,:),'--', 'LineWidth',2, 'Color','black');
hold on
p8=plot(rr, Ba(18,:),'--','LineWidth',2,  'Color','black');
hold on
p11=plot(rr, resp(9,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
h1=legend([p1 p3 p5 p7 p11],{'W','B','W^a', 'B^a','response'},'Orientation','horizontal');
p = get(h1,'Position');
p(1) = 0.13;
p(2) = 0;
set(h1,'Position',p);

figure;
subplot(3,3,1)
plot(rr, W(1,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(2,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(1,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(2,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(1,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(2,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(1,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(2,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(1,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(2,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(1,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,2)
plot(rr, W(3,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(4,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(3,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(4,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(3,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(4,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(3,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(4,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(3,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(4,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(2,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,3)
plot(rr, W(5,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(6,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(5,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(6,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(5,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(6,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(5,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(6,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(5,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(6,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(3,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,4)
plot(rr, W(7,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(8,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(7,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(8,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(7,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(8,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(7,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(8,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(7,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(8,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(4,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,5)
plot(rr, W(9,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(10,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(9,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(10,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(9,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(10,:),'-.',  'LineWidth',2,'Color','black');
hold on
plot(rr, JBa(9,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(10,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(9,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(10,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(5,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,6)
plot(rr, W(11,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(12,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(11,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(12,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(11,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(12,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(11,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(12,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(11,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(12,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(6,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,7)
plot(rr, W(13,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(14,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(13,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(14,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(13,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(14,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(13,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(14,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(13,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(14,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(7,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,8)
plot(rr, W(15,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(16,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(15,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(16,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(15,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(16,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(15,:),'--', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(16,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(15,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(16,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(8,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,3,9)
p1=plot(rr, W(17,:),'LineWidth',2, 'Color','black');
hold on
p2=plot(rr, W(18,:),'LineWidth',2, 'Color','black');
hold on
p3=plot(rr, JB(17,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p4=plot(rr, JB(18,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p5=plot(rr, JWa(17,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p6=plot(rr, JWa(18,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p7=plot(rr, JBa(17,:),'--', 'LineWidth',2, 'Color','black');
hold on
p8=plot(rr, JBa(18,:),'--','LineWidth',2,  'Color','black');
hold on
p9=plot(rr, JBstar(17,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
p10=plot(rr, JBstar(18,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
p11=plot(rr, resp(9,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
h1=legend([p1 p3 p5 p7 p9 p11],{'W','JB','JW^a', 'JB^a', 'JB_{\ast}', 'response'},'Orientation','horizontal');
p = get(h1,'Position');
p(1) = 0.13;
p(2) = 0;
set(h1,'Position',p);