%Empirical example for the paper "Confidence Bands
%for Impulse Responses: Bonferroni versus Wald" by
%Helmut Luetkepohl, Anna Staszewska-Bystrova and Peter Winker, 2014.
clear
clc

n=5000;   %number of bootstrap replications
h=60;     %horizon (shock occurs at h=0)
sl=0.32;   %1-nominal coverage rate
nlags=12;  %number of lags in the VAR
%**************************************************************************
% Load series
data_uhlig_agnostic

mx=[series(:,1:3) series(:,6) series(:,5) series(:,4)];

[ct,nvar]=size(mx);

%estimation
[bm, um, sigmam, ym, xm] = olsvar(mx, nlags);

%bootstrap replicates of the response functions, responses based on
%bias-corrected estimators and bootstrapped values of the Wald
%statistic
[bp1,resp,wb]=bpaths(mx,nlags,nvar,ct,h,n);

[wsort,wind]=sort(wb);

W=zeros(2*nvar^2,h+1);                          %W bands
Wa=zeros(2*nvar^2,h+1);                         %Wa bands
WBa=zeros(2*nvar^2,h+1);                        %WBa bands
JWa=zeros(2*nvar^2,h+1);                        %JWa bands
JWBa=zeros(2*nvar^2,h+1);                       %JWBa bands

for c=1:nvar^2
    bb=bp1(n*(c-1)+1:c*n,:);
    bbs=bb(wind(1:round((1-sl)*n))',:);
    W(2*c-1,:)=min(bbs,[],1);
    W(2*c,:)=max(bbs,[],1);
    Wa(2*c-1:2*c,:)=adjW(nvar,sl,n,bb,wind,h);
    [WBa(2*c-1,:),WBa(2*c,:)]=adjB(h+1,W(2*c-1,:),W(2*c,:),bb,n,sl);
end

JWa=JadjW(nvar,sl,n,bp1,wind,h,W);
JWBa=JadjB(h+1,W,bp1,n,sl,nvar);

B=zeros(2*nvar^2,h+1);                          %B bands
Ba=zeros(2*nvar^2,h+1);                         %Ba bands
B1=zeros(2,h+1);

for c=1:nvar^2
    bb1=bp1(n*(c-1)+1:c*n,:);
    if bb1(:,1)==zeros(n,1)
        B1(1,:)=quantile(bb1,sl/(2*(h)));
        B1(2,:)=quantile(bb1,1-sl/(2*(h)));
    else
        B1(1,:)=quantile(bb1,sl/(2*(h+1)));
        B1(2,:)=quantile(bb1,1-sl/(2*(h+1)));
    end
    naive(2*c-1,:)=quantile(bb1,sl/2);
    naive(2*c,:)=quantile(bb1,1-sl/2);

    B(2*c-1:2*c,:)=B1;
    [Ba(2*c-1,:),Ba(2*c,:)]=adjB(h+1,B(2*c-1,:),B(2*c,:),bb1,n,sl);
end

JB=zeros(2*nvar^2,h+1);                         %JB bands
JBa=zeros(2*nvar^2,h+1);                        %JBa bands

mm=nvar^2*h+nvar*((nvar+1)/2);
for c=1:nvar^2
    bb1=bp1(n*(c-1)+1:c*n,:);
    JB(2*c-1,:)=quantile(bb1,sl/(2*(mm)));
    JB(2*c,:)=quantile(bb1,1-sl/(2*(mm)));
end

[JBa]=JadjB(h+1,JB,bp1,n,sl,nvar);

JBstar=zeros(2*nvar^2,h+1);                     %JBstar bands
JBastar=zeros(2*nvar^2,h+1);                    %JBastar bands
Bj1H=zeros(2,h+1);

mm=nvar^2*h+nvar*((nvar+1)/2);
if mm<=nvar^2*nlags+nvar*(nvar+1)/2
    JBstar=JB;
    JBastar=JBa;
end
if mm>nvar^2*nlags+nvar*(nvar+1)/2
    mmstar=nvar^2*nlags+nvar*(nvar+1)/2;
    for c=1:nvar^2
        bb1=bp1(n*(c-1)+1:c*n,:);
        JBstar(2*c-1:2*c,:)=JB_star(bb1,sl,mmstar,h,n,nvar,nlags);
    end
end

[JBastar]=JadjB(h+1,JBstar,bp1,n,sl,nvar);

r=[0;ones(h,1)];
rr=cumsum(r);
figure;
subplot(3,2,1)
plot(rr, W(37,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(38,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(37,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(38,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(37,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(38,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(37,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(38,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(19,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,2)
plot(rr, W(39,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(40,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(39,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(40,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(39,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(40,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(39,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(40,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(20,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,3)
plot(rr, W(41,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(42,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(41,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(42,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(41,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(42,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(41,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(42,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(21,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,4)
plot(rr, W(43,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(44,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(43,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(44,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(43,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(44,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Ba(43,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(44,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(22,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,5)
plot(rr, W(45,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(46,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, B(45,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, B(46,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, Wa(45,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, Wa(46,:),'-.',  'LineWidth',2,'Color','black');
hold on
plot(rr, Ba(45,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, Ba(46,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, resp(23,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,6)
p1=plot(rr, W(47,:),'LineWidth',2, 'Color','black');
hold on
p2=plot(rr, W(48,:),'LineWidth',2, 'Color','black');
hold on
p3=plot(rr, B(47,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p4=plot(rr, B(48,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p5=plot(rr, Wa(47,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p6=plot(rr, Wa(48,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p7=plot(rr, Ba(47,:),'--', 'LineWidth',2,  'Color','black');
hold on
p8=plot(rr, Ba(48,:),'--', 'LineWidth',2,  'Color','black');
hold on
p11=plot(rr, resp(24,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
h1=legend([p1 p3 p5 p7 p11],{'W','B','W^a', 'B^a','response'},'Orientation','horizontal');
p = get(h1,'Position');
p(1) = 0.13;
p(2) = 0;
set(h1,'Position',p);

figure;
subplot(3,2,1)
plot(rr, W(37,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(38,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(37,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(38,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(37,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(38,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(37,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(38,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(37,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(38,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(19,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,2)
plot(rr, W(39,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(40,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(39,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(40,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(39,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(40,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(39,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(40,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(39,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(40,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(20,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,3)
plot(rr, W(41,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(42,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(41,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(42,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(41,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(42,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(41,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(42,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(41,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(42,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(21,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,4)
plot(rr, W(43,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(44,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(43,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(44,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(43,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(44,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JBa(43,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(44,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(43,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(44,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(22,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,5)
plot(rr, W(45,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, W(46,:),'LineWidth',2, 'Color','black');
hold on
plot(rr, JB(45,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JB(46,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
plot(rr, JWa(45,:),'-.', 'LineWidth',2, 'Color','black');
hold on
plot(rr, JWa(46,:),'-.',  'LineWidth',2,'Color','black');
hold on
plot(rr, JBa(45,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBa(46,:),'--', 'LineWidth',2,  'Color','black');
hold on
plot(rr, JBstar(45,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, JBstar(46,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
plot(rr, resp(23,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
subplot(3,2,6)
p1=plot(rr, W(47,:),'LineWidth',2, 'Color','black');
hold on
p2=plot(rr, W(48,:),'LineWidth',2, 'Color','black');
hold on
p3=plot(rr, JB(47,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p4=plot(rr, JB(48,:), 'LineWidth',1, 'Color','black','Marker','o','MarkerSize',2);
hold on
p5=plot(rr, JWa(47,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p6=plot(rr, JWa(48,:),'-.', 'LineWidth',2, 'Color','black');
hold on
p7=plot(rr, JBa(47,:),'--', 'LineWidth',2,  'Color','black');
hold on
p8=plot(rr, JBa(48,:),'--', 'LineWidth',2,  'Color','black');
hold on
p9=plot(rr, JBstar(47,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
p10=plot(rr, JBstar(48,:), 'LineWidth',1, 'Color','black','Marker','v','MarkerSize',2);
hold on
p11=plot(rr, resp(24,:), 'LineWidth',1,'Color','black');
hold on
line([0 h+1],[0 0],'LineStyle','--','Color','black')
xlim([0 h+1]);
hold off
h1=legend([p1 p3 p5 p7 p9 p11],{'W','JB','JW^a', 'JB^a', 'JB_{\ast}', 'response'},'Orientation','horizontal');
p = get(h1,'Position');
p(1) = 0.13;
p(2) = 0;
set(h1,'Position',p);